(* Authors: Cláudia Nalon & Maria Júlia Dias Lima *)

Section syntax.

  (** The set of well-formed formulae of the monomodal logic K is built from an enumerable set of propositional symbols: *)

Definition Props := nat.

(** and a set of constants: *)

Inductive Const: Set := tt | ff.

(** where tt represent verum and ff represents falsum. The set of formulae is inductively defined as follows: *)

Inductive formula : Type :=
  | PropsF : Props -> formula
  | ConstF : Const -> formula
  | Not : formula -> formula
  | And : formula -> formula -> formula
  | Or : formula -> formula -> formula
  | Imp : formula -> formula -> formula
  | Box : formula -> formula
  | Diamond : formula -> formula.

(** The size of a formula is defined in the usual way: *)

Fixpoint size (f: formula) : nat :=
  match f with
  | PropsF p => 1
  | ConstF _ => 1
  | Not g => 1 + size g
  | And f g => 1 + (size f) + (size g)
  | Or f g => 1 + (size f) + (size g)
  | Imp f g => 1 + (size f) + (size g)
  | Box f => 1 + (size f)
  | Diamond f => 1 + (size f)
  end.

End syntax.
